<?php
/**
 * Adds gg_Contact_Widget widget.
 */
class gg_Working_Hours_Widget extends WP_Widget {

	/**
	 * Register widget with WordPress.
	 */
	function __construct() {
		parent::__construct(
			'gg_working_hours_widget', // Base ID
			__('Working Hours Widget', 'okthemes'), // Name
			array( 'description' => __( 'Display your business working hours', 'okthemes' ), 'classname' => 'working_hours', ) // Args
		);
	}

	/**
	 * Front-end display of widget.
	 */
	public function widget( $args, $instance ) {
		$title = apply_filters( 'widget_title', $instance['title'] );

		$monday_friday = ! empty( $instance['monday_friday'] ) ? $instance['monday_friday'] : '';
		$saturday = ! empty( $instance['saturday'] ) ? $instance['saturday'] : '';
		$sunday = ! empty( $instance['sunday'] ) ? $instance['sunday'] : '';
		$other_details = ! empty( $instance['other_details'] ) ? $instance['other_details'] : '';

		echo $args['before_widget'];

		if ( ! empty( $title ) )
			echo $args['before_title'] . $title . $args['after_title'];

		echo '<ul class="list-unstyled list-inline">';

		if ( $other_details )
			echo '<li class="other-details">'.$other_details.'</li>';

		if ( $monday_friday )
			echo '<li><strong>' . __('Monday - Friday: ', 'okthemes') . '</strong> '.$monday_friday.' </li>';

		if ( $saturday )
			echo '<li><strong>' . __('Saturday: ', 'okthemes') . '</strong> '.$saturday.' </li>';

		if ( $sunday )
			echo '<li><strong>' . __('Sunday: ', 'okthemes') . '</strong> '.$sunday.' </li>';

		echo '</ul>';

		echo $args['after_widget'];
	}
	

	/**
	 * Back-end widget form.
	 */
	public function form( $instance ) {
		
		$title = isset( $instance['title'] ) ? $instance['title'] : __( 'Working hours', 'okthemes' );

		$monday_friday = isset( $instance['monday_friday'] ) ? $instance['monday_friday'] : '';
		$saturday = isset( $instance['saturday'] ) ? $instance['saturday'] : '';
		$sunday = isset( $instance['sunday'] ) ? $instance['sunday'] : '';
		$other_details = esc_textarea($instance['other_details']);

		?>
		
		<!-- Widget Title: Text Input -->
		<p>
			<label for="<?php echo $this->get_field_id( 'title' ); ?>"><?php _e('Title:', 'okthemes'); ?></label>
			<input id="<?php echo $this->get_field_id( 'title' ); ?>" name="<?php echo $this->get_field_name( 'title' ); ?>" value="<?php echo $instance['title']; ?>" class="widefat" />
		</p>
		<!-- Monday - Friday: Text Input -->
		<p>
			<label for="<?php echo $this->get_field_id( 'monday_friday' ); ?>"><?php _e('Monday - Friday:', 'okthemes'); ?></label>
			<input id="<?php echo $this->get_field_id( 'monday_friday' ); ?>" name="<?php echo $this->get_field_name( 'monday_friday' ); ?>" value="<?php echo $instance['monday_friday']; ?>" class="widefat" />
		</p>
		<!-- Saturday: Text Input -->
		<p>
			<label for="<?php echo $this->get_field_id( 'saturday' ); ?>"><?php _e('Saturday:', 'okthemes'); ?></label>
			<input id="<?php echo $this->get_field_id( 'saturday' ); ?>" name="<?php echo $this->get_field_name( 'saturday' ); ?>" value="<?php echo $instance['saturday']; ?>" class="widefat" />
		</p>
		<!-- Sunday: Text Input -->
		<p>
			<label for="<?php echo $this->get_field_id( 'sunday' ); ?>"><?php _e('Sunday:', 'okthemes'); ?></label>
			<input id="<?php echo $this->get_field_id( 'sunday' ); ?>" name="<?php echo $this->get_field_name( 'sunday' ); ?>" value="<?php echo $instance['sunday']; ?>" class="widefat" />
		</p>
		<!-- Other details: Text Input -->
		<p>
			<label for="<?php echo $this->get_field_id( 'other_details' ); ?>"><?php _e('Other details:', 'okthemes'); ?></label>
			<textarea class="widefat" id="<?php echo $this->get_field_id('other_details'); ?>" name="<?php echo $this->get_field_name('other_details'); ?>"><?php echo $other_details; ?></textarea>
		</p>
		<?php 
	}


	/**
	 * Sanitize widget form values as they are saved.
	 */
	public function update( $new_instance, $old_instance ) {
		$instance = array();

		$instance['title'] = ( ! empty( $new_instance['title'] ) ) ? strip_tags( $new_instance['title'] ) : '';
		$instance['monday_friday'] = ( ! empty( $new_instance['monday_friday'] ) ) ? strip_tags( $new_instance['monday_friday'] ) : '';
		$instance['other_details'] =  $new_instance['other_details'];
		$instance['saturday'] = ( ! empty( $new_instance['saturday'] ) ) ? strip_tags( $new_instance['saturday'] ) : '';
		$instance['sunday'] = ( ! empty( $new_instance['sunday'] ) ) ? strip_tags( $new_instance['sunday'] ) : '';
		
		return $instance;
	}


} // class gg_Working_Hours_Widget

// register gg_Working_Hours_Widget 
function register_gg_working_hours_widget() {
    register_widget( 'gg_Working_Hours_Widget' );
}
add_action( 'widgets_init', 'register_gg_working_hours_widget' );