<?php
/**
 * Template Name: Contact Page
 * Description: Page template with a content container and right sidebar.
 *
 * @package WordPress
 * @subpackage Smarty
 */
get_header(); ?>

<?php
$contact_map = rwmb_meta( 'gg_contact_map' );
$contact_map_latitude = rwmb_meta( 'gg_contact_map_latitude' );
$contact_map_longitude = rwmb_meta( 'gg_contact_map_longitude' );
$contact_zoom = rwmb_meta( 'gg_contact_zoom' );
$contact_map_infowindow = rwmb_meta( 'gg_contact_map_infowindow' );
$contact_map_infowindow_title = rwmb_meta( 'gg_contact_map_infowindow_title' );

$contact_recaptcha = rwmb_meta( 'gg_contact_recaptcha' );
$contact_recaptcha_private_key = rwmb_meta( 'gg_contact_recaptcha_private_key' );
$contact_recaptcha_public_key = rwmb_meta( 'gg_contact_recaptcha_public_key' );

if ($contact_map) {
    wp_enqueue_script('gmaps');
    wp_enqueue_script('google-map');
}

wp_enqueue_script('jvalidate');

$page_layout = rwmb_meta('gg_page_layout_select');

$page_content_class = 'col-xs-12 col-md-9';
$page_sidebar_class = 'col-xs-12 col-md-3';
$page_heading_position_align = 'text-align-left';

switch ($page_layout) {
    case "with_right_sidebar":
        $page_content_class = 'col-xs-12 col-md-9 pull-left';
        $page_sidebar_class = 'col-xs-12 col-md-3 pull-right';
        break;
    case "with_left_sidebar":
        $page_content_class = 'col-xs-12 col-md-9 pull-right';
        $page_sidebar_class = 'col-xs-12 col-md-3 pull-left';
        break;
    case "no_sidebar":
        $page_content_class = 'col-xs-12 col-md-12';
        break;        
    case "fullscreen":
        $page_content_class = '';
        break;    
}

//Contact form
$contact_form_headline = rwmb_meta( 'gg_contact_form_headline' );
$contact_page_email = rwmb_meta( 'gg_contact_page_email' );
$contact_page_success = rwmb_meta( 'gg_contact_page_success_msg' );
$contact_page_error = rwmb_meta( 'gg_contact_page_error_msg' );

$commentError ='';
$emailError ='';
$nameError ='';
$subjectError ='';

//If the form is submitted
if(isset($_POST['submitted'])) {

    if ($contact_recaptcha) {
        //load recaptcha file
        require_once PARENT_DIR . '/lib/captcha/recaptchalib.php';
        //enter your recaptcha private key
        $privatekey = $contact_recaptcha_private_key;
        //check recaptcha fields
         $resp = recaptcha_check_answer ($privatekey,
        $_SERVER["REMOTE_ADDR"],
        $_POST["recaptcha_challenge_field"],
        $_POST["recaptcha_response_field"]);
    }

    //Check to see if the honeypot captcha field was filled in
    if(trim($_POST['checking']) !== '') {
        $captchaError = true;
    } else {
    
        //Check to make sure that the name field is not empty
        if(trim($_POST['contactName']) === '') {
            $nameError = 'You forgot to enter your name.';
            $hasError = true;
        } else {
            $name = trim($_POST['contactName']);
        }

        //Check to make sure that the name field is not empty
        if(trim($_POST['subjectName']) === '') {
            $subjectError = 'You forgot to enter your subject.';
            $hasError = true;
        } else {
            $subject = trim($_POST['subjectName']);
        }
        
        //Check to make sure sure that a valid email address is submitted
        if(trim($_POST['email']) === '')  {
            $emailError = 'You forgot to enter your email address.';
            $hasError = true;
        } else if (!preg_match("/^[[:alnum:]][a-z0-9_.-]*@[a-z0-9.-]+\.[a-z]{2,4}$/i", trim($_POST['email']))) {
            $emailError = 'You entered an invalid email address.';
            $hasError = true;
        } else {
            $email = trim($_POST['email']);
        }
            
        //Check to make sure comments were entered  
        if(trim($_POST['comments']) === '') {
            $commentError = 'You forgot to enter your comments.';
            $hasError = true;
        } else {
            if(function_exists('stripslashes')) {
                $comments = stripslashes(trim($_POST['comments']));
            } else {
                $comments = trim($_POST['comments']);
            }
        }
            
        //If there is no error, send the email
        if ($contact_recaptcha) {
            if ( ($resp->is_valid) && !isset($hasError) ) {
                $emailTo = $contact_page_email;
                if (!isset($emailTo) || ($emailTo == '') ){
                    $emailTo = get_option('admin_email');
                }
                $subject_send = $subject;
                $body = "Name: $name \n\nEmail: $email \n\nComments: $comments";
                $headers = 'From: My Site <'.$emailTo.'>' . "\r\n" . 'Reply-To: ' . $email;
                
                wp_mail($emailTo, $subject_send, $body, $headers);
                $emailSent = true;

            }
        } else {
            if (!isset($hasError)) {
                $emailTo = $contact_page_email;
                if (!isset($emailTo) || ($emailTo == '') ){
                    $emailTo = get_option('admin_email');
                }
                $subject_send = $subject;
                $body = "Name: $name \n\nEmail: $email \n\nComments: $comments";
                $headers = 'From: My Site <'.$emailTo.'>' . "\r\n" . 'Reply-To: ' . $email;
                
                wp_mail($emailTo, $subject_send, $body, $headers);
                $emailSent = true;

            }
        } 

        // if there are errors in captcha fields set an error variable
        if (!($resp->is_valid) && $contact_recaptcha){
            $captchaErrorMsg = true;
        }
    }
}

?>

<?php if ($contact_map) { ?>
<script type="text/javascript">
  var image = '<?php echo get_template_directory_uri(); ?>/images/map-marker.png';
  var $j = jQuery.noConflict();
  
  $j(document).ready(function(){

      $j("#map").gMap({
        controls: {
            panControl: true,
            zoomControl: true,
            mapTypeControl: true,
            scaleControl: true,
            streetViewControl: true,
            overviewMapControl: true
        },
        scrollwheel: false,
        maptype: 'ROADMAP',
        markers: [
            {
                latitude: <?php echo $contact_map_latitude; ?>,
                longitude: <?php echo $contact_map_longitude; ?>,
                <?php $contact_map_infowindow = str_replace(array("\r\n", "\r", "\n"), "", $contact_map_infowindow); ?>
                html: "<?php echo html_entity_decode($contact_map_infowindow); ?>",
                popup: true
            }
            
        ],
        icon: {
            image: image, 
            iconsize: [26, 46],
            iconanchor: [12, 46]
        },
        latitude: <?php echo $contact_map_latitude; ?>,
        longitude: <?php echo $contact_map_longitude; ?>,
        zoom: <?php echo $contact_zoom; ?>
    });

  });
</script>
<?php } ?>

<?php smarty_page_header(); ?>

<?php smarty_page_header_slider(); ?>

<!-- Begin - Map -->
<?php if ($contact_map) { ?>
<div class="contact-map">
    <div id="map"></div>
</div>
<?php } ?>
<!-- End - Map -->

<section id="content" <?php echo $page_layout == 'fullscreen' ? 'class="page-fullscreen"' : '' ;?>>

    <?php echo $page_layout == 'fullscreen' ? '' : '<div class="container"><div class="row">' ;?>

        <div class="<?php echo $page_content_class; ?>">
            
            <?php while ( have_posts() ) : the_post(); ?>
                <?php get_template_part( 'parts/part', 'page' ); ?>
                <?php comments_template( '', true ); ?>
            <?php endwhile; ?>

            <div class="clearfix"></div>

            <div class="contact-form-wrapper">
            <?php if(isset($emailSent) && $emailSent == true) { ?>
                <div class="thanks">
                    <p><?php echo $contact_page_success;?></p>
                </div>
            <?php } ?>
                
            <?php if(isset($hasError) || isset($captchaError)) { ?>
                <p class="error"><?php echo $contact_page_error;?></p>
            <?php } ?>

            <?php if ($captchaErrorMsg && $contact_recaptcha){ ?> 
                <p class="error">Captcha error. Please, type the check-words again.</p>
            <?php } ?>

            <?php if ($contact_recaptcha){ ?>
            <script type="text/javascript">
                var RecaptchaOptions = {
                    theme : 'clean'
                };
            </script>
            <?php } ?>
                    
            <form action="<?php the_permalink(); ?>" class="<?php if(isset($emailSent) && $emailSent == true) { ?> form-finished <?php } ?>" id="contactForm" method="post">
                <div class="form-inline row">
                    <div class="form-group col-xs-12 col-md-4">
                        <label class="sr-only" for="contactName"><?php _e( 'Name (required)', 'okthemes' ); ?></label>
                        <input placeholder="<?php _e( 'Name (required)', 'okthemes' ); ?>" type="text" name="contactName" id="contactName" value="<?php if(isset($_POST['contactName'])) echo $_POST['contactName'];?>" class="required" />
                    </div>    
                    <div class="form-group col-xs-12 col-md-4">    
                        <label class="sr-only" for="email"><?php _e( 'Email (required)', 'okthemes' ); ?></label>
                        <input placeholder="<?php _e( 'Email (required)', 'okthemes' ); ?>" type="text" name="email" id="email" value="<?php if(isset($_POST['email']))  echo $_POST['email'];?>" class="required email" />
                    </div>
                    <div class="form-group col-xs-12 col-md-4">
                        <label class="sr-only" for="subjectName"><?php _e( 'Subject (required)', 'okthemes' ); ?></label>
                        <input placeholder="<?php _e( 'Subject (required)', 'okthemes' ); ?>" type="text" name="subjectName" id="subjectName" value="<?php if(isset($_POST['subjectName'])) echo $_POST['subjectName'];?>" class="required" />
                    </div>
                </div>

                <div class="form-group">    
                    <label class="sr-only" for="commentsText"><?php _e( 'Comments (required)', 'okthemes' ); ?></label>
                    <textarea name="comments" id="commentsText" rows="20" cols="30" placeholder="<?php _e( 'Comments (required)', 'okthemes' ); ?>" class="required"><?php if(isset($_POST['comments'])) { if(function_exists('stripslashes')) { echo stripslashes($_POST['comments']); } else { echo $_POST['comments']; } } ?></textarea>
                </div>

                    <label for="checking" class="hidden"><?php _e( 'Empty field', 'okthemes' ); ?></label>
                    <input type="text" name="checking" id="checking" class="hidden" value="<?php if(isset($_POST['checking']))  echo $_POST['checking'];?>" />
                    
                    <?php
                    if ($contact_recaptcha){
                        //load recaptcha file
                        require_once PARENT_DIR . '/lib/captcha/recaptchalib.php';
                        // enter your public key
                        $publickey = $contact_recaptcha_public_key;
                        // display recaptcha test fields
                        echo recaptcha_get_html($publickey);
                    }
                    ?>

                    <input type="hidden" name="submitted" id="submitted" value="true" />
                    <button type="submit" class="btn btn-primary"><?php _e( 'Send email', 'okthemes' ); ?></button>
                </ul>
            </form>

            </div><!--Close .contact-form-wrapper -->

            <script type="text/javascript">
            var $j = jQuery.noConflict();
            $j(document).ready(function(){
                $j("#contactForm").validate();
            });
            </script>

        </div><!-- /.col-8 col-sm-8 col-lg-8 -->

        <?php if (($page_layout !== 'no_sidebar') && ($page_layout !== 'fullscreen')) { ?>
        <div class="<?php echo $page_sidebar_class; ?>">
            <aside class="sidebar-nav">
                <?php get_sidebar(); ?>
            </aside>
            <!--/aside .sidebar-nav -->
        </div><!-- /.col-4 col-sm-4 col-lg-4 -->
        <?php } ?>

    <?php echo $page_layout == 'fullscreen' ? '' : '</div></div>' ;?>
</section>

<?php smarty_page_footer_message_box(); ?>

<?php get_footer(); ?>